summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/alter.c
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/3rdparty/kexisql3/src/alter.c
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/alter.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/alter.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/kexi/3rdparty/kexisql3/src/alter.c b/kexi/3rdparty/kexisql3/src/alter.c
index eba01e29..73c49b1f 100644
--- a/kexi/3rdparty/kexisql3/src/alter.c
+++ b/kexi/3rdparty/kexisql3/src/alter.c
@@ -53,7 +53,7 @@ static void renameTableFunc(
/* The principle used to locate the table name in the CREATE TABLE
** statement is that the table name is the first token that is immediatedly
- ** followed by a left parenthesis - TK_LP.
+ ** followed by a left tqparenthesis - TK_LP.
*/
if( zSql ){
do {
@@ -231,7 +231,7 @@ static void reloadTableSchema(Parse *pParse, Table *pTab, const char *zName){
#ifndef SQLITE_OMIT_TRIGGER
/* Now, if the table is not stored in the temp database, reload any temp
- ** triggers. Don't use IN(...) in case SQLITE_OMIT_SUBQUERY is defined.
+ ** triggers. Don't use IN(...) in case SQLITE_OMIT_SUBTQUERY is defined.
*/
if( (zWhere=whereTempTriggers(pParse, pTab)) ){
sqlite3VdbeOp3(v, OP_ParseSchema, 1, 0, zWhere, P3_DYNAMIC);
@@ -407,7 +407,7 @@ void sqlite3AlterFinishAddColumn(Parse *pParse, Token *pColDef){
pDflt = 0;
}
/* Check that the new column is not specified as PRIMARY KEY or UNIQUE.
** If there is a NOT NULL constraint, then the default value for the
** column must not be NULL.
*/
@@ -416,7 +416,7 @@ void sqlite3AlterFinishAddColumn(Parse *pParse, Token *pColDef){
return;
}
if( pNew->pIndex ){
- sqlite3ErrorMsg(pParse, "Cannot add a UNIQUE column");
+ sqlite3ErrorMsg(pParse, "Cannot add a UNITQUE column");
return;
}
if( pCol->notNull && !pDflt ){
@@ -407,7 +407,7 @@ void sqlite3AlterFinishAddColumn(Parse *pParse, Token *pColDef){
pDflt = 0;
}
- /* Check that the new column is not specified as PRIMARY KEY or UNIQUE.
+ /* Check that the new column is not specified as PRIMARY KEY or UNITQUE.
** If there is a NOT NULL constraint, then the default value for the
** column must not be NULL.